@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2003, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -203,7 +203,7 @@ void draw_surfaces(void)
 {
    Surface *su;
    double c0[2],c1[2],c2[2],c3[2];
-   double ca[2],cc[2];
+   double cc[2];
 
    if (numsurfaces==0) return;
    SetLineAttributes(0, GDK_LINE_SOLID, GDK_CAP_ROUND, GDK_JOIN_ROUND);
@@ -212,34 +212,45 @@ void draw_surfaces(void)
          SetForeground(&c_surf);
       else
          SetForeground(&c_back);
+      proj(&su->pc,cc);
+      proj(&su->p0,c0);
+      proj(&su->p1,c1);
       switch (su->type) {
          case SU_rect:
          case SU_arb:
-            proj(&su->pa,ca);
-            proj(&su->pc,cc);
-            proj(&su->p0,c0);
-            proj(&su->p1,c1);
             c2[0]=2*cc[0]-c0[0]; c2[1]=2*cc[1]-c0[1];
             c3[0]=2*cc[0]-c1[0]; c3[1]=2*cc[1]-c1[1];
-            if (su->type!=SU_arb) {
-               /* draw border: */
-               DrawLine(c0[0], c0[1], c1[0], c1[1]);
-               DrawLine(c1[0], c1[1], c2[0], c2[1]);
-               DrawLine(c2[0], c2[1], c3[0], c3[1]);
-               DrawLine(c3[0], c3[1], c0[0], c0[1]);
-            }
-            /* draw diagonals: */
-            DrawLine(c0[0], c0[1], c2[0], c2[1]);
-            DrawLine(c1[0], c1[1], c3[0], c3[1]);
-            if (su->type==SU_arb) {
-               /* draw additional diagonals */
-               DrawLine(0.7071*(c0[0]+c1[0])-0.4142*cc[0], 0.7071*(c0[1]+c1[1])-0.4142*cc[1], 0.7071*(c2[0]+c3[0])-0.4142*cc[0], 0.7071*(c2[1]+c3[1])-0.4142*cc[1]);
-               DrawLine(0.7071*(c0[0]+c3[0])-0.4142*cc[0], 0.7071*(c0[1]+c3[1])-0.4142*cc[1], 0.7071*(c2[0]+c1[0])-0.4142*cc[0], 0.7071*(c2[1]+c1[1])-0.4142*cc[1]);
-            }
+            break;
+         case SU_quad:
+            proj(&su->p3,c3);
+            /* fallthrough */
+         case SU_tri:
+            proj(&su->p2,c2);
             break;
       }
+      if (su->type==SU_tri) {
+         /* triangle; draw border: */
+         DrawLine(c0[0], c0[1], c1[0], c1[1]);
+         DrawLine(c1[0], c1[1], c2[0], c2[1]);
+         DrawLine(c2[0], c2[1], c0[0], c0[1]);
+      } else {
+         /* joint drawing code for all other shapes, which are drawn as various quadrilaterals */
+         /* draw diagonals: */
+         DrawLine(c0[0], c0[1], c2[0], c2[1]);
+         DrawLine(c1[0], c1[1], c3[0], c3[1]);
+         if (su->type!=SU_arb) {
+            /* draw border: */
+            DrawLine(c0[0], c0[1], c1[0], c1[1]);
+            DrawLine(c1[0], c1[1], c2[0], c2[1]);
+            DrawLine(c2[0], c2[1], c3[0], c3[1]);
+            DrawLine(c3[0], c3[1], c0[0], c0[1]);
+         } else {
+            /* draw additional diagonals */
+            DrawLine(0.7071*(c0[0]+c1[0])-0.4142*cc[0], 0.7071*(c0[1]+c1[1])-0.4142*cc[1], 0.7071*(c2[0]+c3[0])-0.4142*cc[0], 0.7071*(c2[1]+c3[1])-0.4142*cc[1]);
+            DrawLine(0.7071*(c0[0]+c3[0])-0.4142*cc[0], 0.7071*(c0[1]+c3[1])-0.4142*cc[1], 0.7071*(c2[0]+c1[0])-0.4142*cc[0], 0.7071*(c2[1]+c1[1])-0.4142*cc[1]);
+         }
+      }
    }
-
 }
 
 
