@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 2002-2003, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 2002-2005, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -328,11 +328,11 @@ PRINTF(("============ add_to_mask: %g %g\n",q->a,p->a));
       if (q->hp) q->hp->maskpoint=q;
       return;
    }
-   if (fabs(p->x-q->x)<1e-8 && fabs(p->y-q->y)<1e-8) {
+   if (fabs(p->x-q->x)<1e-8 && fabs(p->y-q->y)<1e-8 && !p->del) {
       mpfree(q);
       return;
    }
-   if (p->next && fabs(p->next->x-q->x)<1e-8 && fabs(p->next->y-q->y)<1e-8) {
+   if (p->next && fabs(p->next->x-q->x)<1e-8 && fabs(p->next->y-q->y)<1e-8 && !p->next->del) {
       mpfree(q);
       return;
    }
@@ -1198,6 +1198,7 @@ char *opaque_impossible(Radpattern *rp)
    double a;
    if (rp->gtheta[0]*180/M_PI>0.1) return "theta range does not start at 0 degrees";
    a=rp->gtheta[rp->numtheta-1]*180/M_PI;
+   if (a>180.1) return "theta range continues beyond 180 degrees";
    if ((a<89.9 || a>90.1) && a<179.9) return "theta range does not go on until either 90 or 180 degrees";
    if (rp->gphi[0]*180/M_PI>0.1) return "phi range does not start at 0 degrees";
    if (rp->gphi[rp->numphi-1]*180/M_PI<271) return "phi range does not go on until almost 360 degrees";
