@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2006, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006,2011, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -358,12 +358,15 @@ int read_nec_GM(char *s)    /* GM -> coordinate transformation */
    double co,si;
    Wire *w00,*w0,*w1,*wlast;
    Surface *s0,*s1;
+   double its_double;
 
    removecommas(s);
    rox=roy=roz=xs=ys=zs=its=0;
-   i=sscanf(s,"GM%d%d%lg%lg%lg%lg%lg%lg%d",&itsi,&nrpt,&rox,&roy,&roz,&xs,&ys,&zs,&its);
+   i=sscanf(s,"GM%d%d%lg%lg%lg%lg%lg%lg%lg",&itsi,&nrpt,&rox,&roy,&roz,&xs,&ys,&zs,&its_double);
    if (i<2) return Err_scan;
 
+   its = (int)(its_double+0.5);   // round to double; the detour via double is needed because some programs write something like 1.1e1 instead of 11 in this field, and this is not forbidden according to the specification
+
    rox*=M_PI/180.0; roy*=M_PI/180.0; roz*=M_PI/180.0;
 
    mat[0]=mat[4]=mat[8]=1;
