@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2006, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006,2011, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -782,9 +782,15 @@ int read_nec_output(FILE *f)          /* tries to read NEC output data from f; r
          ne->d[neco_maxgain_vert]=-DBL_MAX;
          ne->d[neco_maxgain_lhcp]=-DBL_MAX;
          ne->d[neco_maxgain_rhcp]=-DBL_MAX;
+         ne->d[neco_zr]=0;
+         ne->d[neco_zi]=0;
+         ne->d[neco_swr]=0;
+         ne->d[neco_zphi]=0;
+         ne->d[neco_zabs]=0;
       }
 
       /* find and read the input impedance, and calculate the SWR */
+#if 0
       do fgets(s,200,f);  while (!feof(f) && !strstr(s,"ANTENNA INPUT PARAMETERS"));
       if (feof(f)) break;
       do {  /* skip lines until a line starting with a digit is found */
@@ -798,8 +804,10 @@ int read_nec_output(FILE *f)          /* tries to read NEC output data from f; r
       ne->d[neco_zi]=zi;
       calcswr(ne);
       calcphiabs(ne);
+#endif
 
       /* check whether radiation pattern data is included for this frequency, and if so, read it */
+      /* check also whether input impedance data is included for this frequency, and if so, read it */
       /* check also whether currents and/or charge data is included for this frequency, and if so, read it */
       /* check also whether near field data is included for this frequency, and if so, read it */
       do {
@@ -831,6 +839,21 @@ int read_nec_output(FILE *f)          /* tries to read NEC output data from f; r
             if (!ne->rp) return 1;
             if (new_rp_index<0) new_rp_index=ne-neco;
          }
+
+         if (strstr(s,"ANTENNA INPUT PARAMETERS")) {
+            do {  /* skip lines until a line starting with a digit is found */
+               fgets(s,200,f);  
+               p=s;
+               while (*p==' ') p++;
+            } while (!feof(f) && !isdigit(*p));
+            if ((p=strchr(s,'*'))) *p=' ';
+            if (sscanf(s,"%*i%*i%*g%*g%*g%*g%lg%lg",&zr,&zi)!=2) continue;
+            ne->d[neco_zr]=zr;
+            ne->d[neco_zi]=zi;
+            calcswr(ne);
+            calcphiabs(ne);
+         }
+
       } while (!feof(f) && !strstr(s,"FREQUENCY"));
 
       if (ne->cu) normalize_currents(ne->cu);
