@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2006, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006,2011, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -14,6 +14,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
+#include <locale.h>
 
 #ifndef NO_GETOPT
   #include <getopt.h>
@@ -373,6 +374,8 @@ int main(int argc,char **argv)
    initX(&argc,argv);
    inputfilename=NULL;
 
+   setlocale(LC_NUMERIC,"C");
+
    wires=mymalloc(maxwires*sizeof(Wire));
    surfaces=mymalloc(maxsurfaces*sizeof(Surface));
    excis=mymalloc(maxexcis*sizeof(Exci));
