@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2006, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006,2011, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -244,7 +244,7 @@ int write_png(int which,const char *filename)
    int x,y;
    png_structp pp;
    png_infop ip;
-   char *buf;
+   unsigned char *buf;
    png_color pal[NC];
    int i;
 
@@ -360,7 +360,7 @@ gint resize_event(GtkWidget *w,GdkEventConfigure *ev,gpointer dummy)
    winsizex=ev->width;
    winsizey=ev->height;
    gdk_pixmap_unref(gbackg);
-   gbackg=gdk_pixmap_new(w->window,winsizex,winsizey,depth);
+   gbackg=gdk_pixmap_new(w->window,winsizex,winsizey,gdk_drawable_get_depth(w->window));
    calcproj();
    redraw=1;
 #if 0
@@ -876,7 +876,7 @@ gint resize_event2(GtkWidget *w,GdkEventConfigure *ev,gpointer dummy)
    win2sizex=ev->width;
    win2sizey=ev->height;
    gdk_pixmap_unref(gbackg2);
-   gbackg2=gdk_pixmap_new(w->window,win2sizex,win2sizey,depth);
+   gbackg2=gdk_pixmap_new(w->window,win2sizex,win2sizey,gdk_drawable_get_depth(w->window));
 
    redraw2=1;
    return TRUE;
@@ -1386,7 +1386,7 @@ void maininitX(int really)
          winsizex=toprow->requisition.width;
          calcproj();
       }
-      gbackg=gdk_pixmap_new(w->window,winsizex,winsizey,depth);
+      gbackg=gdk_pixmap_new(w->window,winsizex,winsizey,gdk_drawable_get_depth(w->window));
 
       upd_msg();
 
@@ -1482,7 +1482,7 @@ void maininitX(int really)
 
       ggc2 = gdk_gc_new(w->window);
 
-      gbackg2=gdk_pixmap_new(w->window,win2sizex,win2sizey,depth);
+      gbackg2=gdk_pixmap_new(w->window,win2sizex,win2sizey,gdk_drawable_get_depth(w->window));
 
       gtk_signal_connect( GTK_OBJECT(w), "expose_event", GTK_SIGNAL_FUNC(expose_event2), NULL);
 
